<?php

include __DIR__."/builtin_extensions.inc";

class A_DOMXPath extends DOMXPath {
  public $___x;
}
test("DOMXPath", new DOMNode);
